@@ -17,6 +17,7 @@ MINIMUM_CONFIG_PLUGINS = [
     'openpaperwork_core.config',
     'openpaperwork_core.config.automatic_plugin_reset',
     'openpaperwork_core.config.backend.configparser',
+    'openpaperwork_core.data_versioning',
     'openpaperwork_core.display.print',
     'openpaperwork_core.frozen',
     'openpaperwork_core.fs.python',
@@ -29,7 +30,6 @@ MINIMUM_CONFIG_PLUGINS = [
 
 
 RECOMMENDED_PLUGINS = [
-    'openpaperwork_core.cmd.chkdeps',
     'openpaperwork_core.external_apps.dbus',
     'openpaperwork_core.external_apps.windows',
     'openpaperwork_core.external_apps.xdg',
@@ -41,10 +41,17 @@ RECOMMENDED_PLUGINS = [
     'openpaperwork_core.perfcheck.log',
     'openpaperwork_core.resources.frozen',
     'openpaperwork_core.resources.setuptools',
+    'openpaperwork_core.sqlite',
     'openpaperwork_core.thread.pool',
+    'openpaperwork_core.urls',
     'openpaperwork_core.work_queue.default',
 ]
 
+if os.name != 'nt':
+    RECOMMENDED_PLUGINS += [
+        'openpaperwork_core.cmd.chkdeps',
+    ]
+
 
 def _(s):
     return gettext.dgettext('openpaperwork_core', s)
@@ -156,12 +163,8 @@ class Core(object):
             return self.plugins[module_name]
 
         LOGGER.info("Loading plugin '%s' ...", module_name)
-        try:
-            module = importlib.import_module(module_name)
-            return self._load_module(module_name, module)
-        except Exception as exc:
-            LOGGER.error("Failed to load '%s'", module_name, exc_info=exc)
-            return None
+        module = importlib.import_module(module_name)
+        return self._load_module(module_name, module)
 
     def _load_module(self, module_name, module):
         """
@@ -281,14 +284,7 @@ class Core(object):
 
         LOGGER.info("Initializing plugin '%s' ...", type(plugin))
         stack.remove(plugin)
-        try:
-            plugin.init(self)
-        except Exception as exc:
-            LOGGER.error(
-                "Failed to initialized plugin '%s'",
-                type(plugin), exc_info=exc
-            )
-            return nb
+        plugin.init(self)
 
         self._register_plugin(plugin)
         nb += 1
@@ -451,7 +447,7 @@ class Core(object):
             )
         if self.log_all:
             print(
-                "[{}] call_all({}, args={}, kwargs={}) -> {}:{}".format(
+                "[{}] call_one({}, args={}, kwargs={}) -> {}:{}".format(
                     time.time(), callback_name, args, kwargs,
                     callbacks[0][0], callbacks[0][2]
                 )
@@ -500,17 +496,12 @@ class Core(object):
             LOGGER.warning("No method '%s' found", callback_name)
         for (priority, plugin, callback) in callbacks:
             if self.log_all:
-                print(
-                    "[{}] call_all({}, args={}, kwargs={}) -> {}:{}".format(
-                        time.time(), callback_name, args, kwargs,
-                        priority, callback
-                    )
-                )
-            try:
-                r = callback(*args, **kwargs)
-            except Exception:
-                LOGGER.error("Callback '%s' failed", str(callback))
-                raise
+                msg = "[{}] call_success({}, args={}, kwargs={}) -> {}:{}"
+                print(msg.format(
+                    time.time(), callback_name, args, kwargs, priority,
+                    callback
+                ))
+            r = callback(*args, **kwargs)
             if r is not None:
                 return r
         return None
