@@ -29,6 +29,7 @@ class Plugin(openpaperwork_core.PluginBase):
         self.windows = []
 
         self.button_validate = None
+        self.button_send_email = None
         self.preciew = None
         self.zoom = None
         self.quality = None
@@ -79,6 +80,10 @@ class Plugin(openpaperwork_core.PluginBase):
                     'paperwork_backend.docexport.pillowfight',
                 ],
             },
+            {
+                'interface': 'fs',
+                'defaults': ['openpaperwork_gtk.fs.gio'],
+            },
             {
                 'interface': 'gtk_mainwindow',
                 'defaults': ['paperwork_gtk.mainwindow.window'],
@@ -106,6 +111,14 @@ class Plugin(openpaperwork_core.PluginBase):
                 'interface': 'work_queue',
                 'defaults': ['openpaperwork_core.work_queue.default'],
             },
+            {
+                'interface': 'external_apps',
+                'defaults': [
+                    'openpaperwork_core.external_apps.dbus',
+                    'openpaperwork_core.external_apps.windows',
+                    'openpaperwork_core.external_apps.xdg',
+                ],
+            },
         ]
 
     def init(self, core):
@@ -127,6 +140,17 @@ class Plugin(openpaperwork_core.PluginBase):
         self.button_validate.connect(
             "clicked", self._on_apply
         )
+        self.button_send_email = self.widget_tree.get_object(
+            "exporter_send_email"
+        )
+        self.button_send_email.connect(
+            "clicked", self._on_send_email
+        )
+        can_send_as_attachment = core.call_success(
+            "external_app_can_send_as_attachment"
+        )
+        if not can_send_as_attachment:
+            self.button_send_email.set_visible(False)
 
         self.zoom = self.widget_tree.get_object("exporter_zoom_adjustment")
         self.zoom.connect("value-changed", self._on_zoom_changed)
@@ -295,9 +319,11 @@ class Plugin(openpaperwork_core.PluginBase):
         t = paperwork_backend.docexport.ExportDataType.OUTPUT_URL_FILE
         if last_output_type == t:
             self.button_validate.set_sensitive(True)
+            self.button_send_email.set_sensitive(True)
         else:
             self._add_combobox(steps, last_output_type, "")
             self.button_validate.set_sensitive(False)
+            self.button_send_email.set_sensitive(False)
 
     def _rebuild_pipeline_from_ui(self):
         LOGGER.info("Rebuilding pipeline from UI")
@@ -315,7 +341,7 @@ class Plugin(openpaperwork_core.PluginBase):
 
     def _hide_preview(self):
         if self.tmp_file_url is not None:
-            self.core.call_all("fs_unlink", self.tmp_file_url, trash=False)
+            self.core.call_success("fs_unlink", self.tmp_file_url, trash=False)
             self.tmp_file_url = None
         if self.renderer is not None:
             self.renderer.close()
@@ -658,6 +684,30 @@ class Plugin(openpaperwork_core.PluginBase):
         # do not use the work queue ; must never be canceled
         promise.schedule()
 
+    def _on_send_email(self, button):
+        (_, file_extensions) = self.pipeline[-1].get_output_mime()
+        (target_file_url, fd) = self.core.call_success(
+            "fs_mktemp", suffix="." + file_extensions[0], on_disk=True
+        )
+        fd.close()  # we only need the name
+        self.core.call_all("mainwindow_back", side="right")
+
+        promise = openpaperwork_core.promise.Promise(
+            self.core, lambda: self.export_input
+        )
+        for pipe in self.pipeline:
+            promise = promise.then(pipe.get_promise(
+                result='final', target_file_url=target_file_url
+            ))
+        promise = promise.then(lambda *args, **kwargs: self.core.call_success(
+            "external_app_send_as_attachment", target_file_url
+        ))
+        promise = promise.then(lambda *args, **kwargs: None)
+        promise = promise.catch(self._on_error)
+
+        # do not use the work queue ; must never be canceled
+        promise.schedule()
+
     def _on_error(self, exc):
         LOGGER.error("Export failed", exc_info=exc)
         notif = self.core.call_success(
